/*
 *			GPAC - MPEG-4 Systems C Development Kit
 *
 *			Copyright (c) Jean Le Feuvre 2000-2003 
 *					All rights reserved
 *
 *  This file is part of GPAC / XIPH.org plugin
 *
 *  GPAC is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *   
 *  GPAC is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *   
 *  You should have received a copy of the GNU General Public License
 *  along with GNU Make; see the file COPYING.  If not, write to
 *  the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. 
 *
 */

#ifndef OGG_IN_H
#define OGG_IN_H

#include <gpac/m4_network.h>
#include <gpac/m4_decoder.h>

NetClientPlugin *OGG_LoadDemux();
void OGG_DeleteDemux(void *ifce);


enum
{
	OGG_VORBIS = 1,
	OGG_SPEEX,
	OGG_FLAC,
	OGG_THEORA
};

typedef struct
{
	u32 type;
	void *opaque;
} OGGWraper;

#ifdef M4_HAS_VORBIS
u32 NewVorbisDecoder(BaseDecoder *ifcd);
void DeleteVorbisDecoder(BaseDecoder *ifcg);
#endif

#ifdef M4_HAS_THEORA
u32 NewTheoraDecoder(BaseDecoder *ifcd);
void DeleteTheoraDecoder(BaseDecoder *ifcg);
#endif

#endif

